@@ -1,10 +1,8 @@
 """Core functionality"""
-import pandas as pd
-
-if int(pd.__version__.split(".")[0]) < 1:
-    from visions.dtypes.boolean import BoolDtype
 
 from visions import types, typesets, utils
+from visions.backends import *
+from visions.declarative import create_type
 from visions.functional import (
     cast_to_detected,
     cast_to_inferred,
@@ -13,3 +11,4 @@ from visions.functional import (
 )
 from visions.types import *
 from visions.typesets import *
+from visions.version import __version__
