@@ -1,19 +1,19 @@
-from typing import Dict, List, Tuple, Type, Union
+from typing import Dict, List, Sequence, Tuple, Type, Union
 
 import pandas as pd
 
 from visions.types.type import VisionsBaseType
 from visions.typesets.typeset import VisionsTypeset
 
+T = Type[VisionsBaseType]
 
-def cast_to_detected(
-    data: Union[pd.Series, pd.DataFrame], typeset: VisionsTypeset
-) -> pd.DataFrame:
-    """Casts a DataFrame into a typeset by first performing column wise type inference against
+
+def cast_to_detected(data: Sequence, typeset: VisionsTypeset) -> Sequence:
+    """Casts a DataFrame into a typeset by first performing column wise type detection against
     a provided typeset
 
     Args:
-        df: the DataFrame to cast
+        data: the DataFrame to cast
         typeset: the Typeset in which we cast
 
     Returns:
@@ -22,14 +22,12 @@ def cast_to_detected(
     return typeset.cast_to_detected(data)
 
 
-def cast_to_inferred(
-    data: Union[pd.Series, pd.DataFrame], typeset: VisionsTypeset
-) -> Tuple[pd.DataFrame, dict]:
+def cast_to_inferred(data: Sequence, typeset: VisionsTypeset) -> Sequence:
     """Casts a DataFrame into a typeset by first performing column wise type inference against
     a provided typeset
 
     Args:
-        df: the DataFrame to cast
+        data: the DataFrame to cast
         typeset: the Typeset in which we cast
 
     Returns:
@@ -38,13 +36,11 @@ def cast_to_inferred(
     return typeset.cast_to_inferred(data)
 
 
-def infer_type(
-    data: Union[pd.Series, pd.DataFrame], typeset: VisionsTypeset
-) -> Union[Dict[str, Type[VisionsBaseType]], Type[VisionsBaseType]]:
+def infer_type(data: Sequence, typeset: VisionsTypeset) -> Union[Dict[str, T], T]:
     """Infer the current types of each column in the DataFrame given the typeset.
 
     Args:
-        df: the DataFrame to infer types on
+        data: the DataFrame to infer types on
         typeset: the Typeset that provides the type context
 
     Returns:
@@ -53,13 +49,11 @@ def infer_type(
     return typeset.infer_type(data)
 
 
-def detect_type(
-    data: Union[pd.Series, pd.DataFrame], typeset: VisionsTypeset
-) -> Union[Dict[str, Type[VisionsBaseType]], Type[VisionsBaseType]]:
+def detect_type(data: Sequence, typeset: VisionsTypeset) -> Union[Dict[str, T], T]:
     """Detect the type in the base graph
 
     Args:
-        df: the DataFrame to detect types on
+        data: the DataFrame to detect types on
         typeset: the Typeset that provides the type context
 
     Returns:
@@ -69,32 +63,37 @@ def detect_type(
 
 
 def compare_detect_inference_frame(
-    df: pd.DataFrame, typeset: VisionsTypeset
-) -> List[Tuple[str, Type[VisionsBaseType], Type[VisionsBaseType]]]:
+    data: Sequence, typeset: VisionsTypeset
+) -> List[Tuple[str, T, T]]:
     """Compare the types given by inference on the base graph and the relational graph
 
     Args:
-        df: the DataFrame to detect types on
+        data: the sequence to detect types on
         typeset: the Typeset that provides the type context
 
     Examples:
-        >>> for column, type_before, type_after in compare_detect_inference_frame(df, typeset):
+        >>> for column, type_before, type_after in compare_detect_inference_frame(data, typeset):
         >>>    print(f"{column} was {type_before} is {type_after}")
 
     See Also:
-        :doc:`type_inference_report_frame <visions.functional.type_inference_report_frame>`: Formatted report of the output of this function
+        :doc:`type_inference_report_frame <visions.functional.type_inference_report_frame>`:
+            Formatted report of the output of this function
     """
     comparisons = []
-    detected_types = detect_type(df, typeset)
-    inferred_types = infer_type(df, typeset)
-    for key in detected_types.keys() & inferred_types.keys():  # type: ignore
-        comparisons.append(
-            (key, detected_types[key], inferred_types[key])  # type: ignore
-        )
+    detected_types = detect_type(data, typeset)
+    inferred_types = infer_type(data, typeset)
+
+    assert isinstance(detected_types, dict) and isinstance(
+        inferred_types, dict
+    )  # Placate the MyPy Gods
+
+    for key in detected_types.keys() & inferred_types.keys():
+        comparisons.append((key, detected_types[key], inferred_types[key]))
     return comparisons
 
 
-def type_inference_report_frame(df, typeset) -> str:
+# TODO: make independent of pandas
+def type_inference_report_frame(df: pd.DataFrame, typeset: VisionsTypeset) -> str:
     """Return formatted report of the output of `compare_detect_inference_frame`.
 
     Args:
@@ -128,13 +127,10 @@ def type_inference_report_frame(df, typeset) -> str:
             change_count += 1
         else:
             fill = "=="
-        report += "{column: <{max_column_length}} {type_before: <{max_type_length}} {fill} {type_after: <{max_type_length}} \n".format(
-            column=column,
-            max_column_length=max_column_length,
-            type_before=str(type_before),
-            type_after=str(type_after),
-            max_type_length=max_type_length,
-            fill=fill,
+        report += (
+            f"{column: <{max_column_length}} {type_before: <{max_type_length}} "
+            f"{fill} "
+            f"{type_after: <{max_type_length}} \n"
         )
     report += (
         "In total {change_count} out of {type_count} types were changed.\n".format(
