@@ -12,9 +12,11 @@ from visions.types.geometry import Geometry
 from visions.types.image import Image
 from visions.types.integer import Integer
 from visions.types.ip_address import IPAddress
+from visions.types.numeric import Numeric
 from visions.types.object import Object
 from visions.types.ordinal import Ordinal
 from visions.types.path import Path
+from visions.types.sparse import Sparse
 from visions.types.string import String
 from visions.types.time import Time
 from visions.types.time_delta import TimeDelta
@@ -46,4 +48,6 @@ __all__ = [
     "URL",
     "Time",
     "EmailAddress",
+    "Sparse",
+    "Numeric",
 ]
