@@ -1,6 +1,6 @@
 import pytest
 
-from visions import Float, Generic, VisionsBaseType, VisionsTypeset
+from visions import Generic, VisionsBaseType, VisionsTypeset
 from visions.relations import IdentityRelation
 
 
@@ -8,23 +8,23 @@ class CustomGeneric(Generic):
     this_value = True
 
 
-class CustomNonGeneric:
+class CustomNonGeneric(VisionsBaseType):
     another_value = False
 
-    @classmethod
-    def get_relations(cls):
+    @staticmethod
+    def get_relations():
         return []
 
 
 def make_test_type(root):
     class CustomFloat(VisionsBaseType):
         @classmethod
-        def contains_op(cls, series):
+        def contains_op(cls, series, state):
             return True
 
-        @classmethod
-        def get_relations(cls):
-            return [IdentityRelation(cls, root)]
+        @staticmethod
+        def get_relations():
+            return [IdentityRelation(root)]
 
     return CustomFloat
 
