@@ -1,8 +1,11 @@
+import copy
 import sys
 
 import pytest
 
-from visions.test.series import get_geometry_series, get_series
+from visions.test.series import get_series
+from visions.test.series_geometry import get_geometry_series
+from visions.test.utils import sequences_equal
 from visions.typesets import CompleteSet
 
 
@@ -37,83 +40,76 @@ def all_relations_tested(series_map):
 
 
 def pytest_generate_tests(metafunc):
-    _test_suite = get_series() + get_geometry_series()
+    _test_suite = get_series()
+    _test_suite.update(get_geometry_series())
     if metafunc.function.__name__ in [
         "test_consistency",
         "test_side_effects",
         "test_multiple_inference",
     ]:
         argsvalues = []
-        for series in _test_suite:
-            args = {"id": str(series.name)}
-            argsvalues.append(pytest.param(series, **args))
+        for name, series in _test_suite.items():
+            args = {"id": name}
+            argsvalues.append(pytest.param(name, series, **args))
 
-        metafunc.parametrize(argnames=["series"], argvalues=argsvalues)
+        metafunc.parametrize(argnames=["name", "series"], argvalues=argsvalues)
 
 
-def test_consistency(series):
+def test_consistency(name, series):
     typeset = CompleteSet()
 
     if (
-        series.name
-        in ["timedelta_series_nat", "date_series_nat", "timestamp_series_nat"]
+        name in ["timedelta_series_nat", "date_series_nat", "timestamp_series_nat"]
         and sys.version_info.major == 3
         and sys.version_info.minor == 7
     ):
         pytest.skip("unsupported configuration")
 
-    initial_type = typeset.detect_type(series.copy(deep=True))
-    converted_type = typeset.infer_type(series.copy(deep=True))
+    initial_type = str(typeset.detect_type(series))
+    converted_type = str(typeset.infer_type(series))
 
     if initial_type != converted_type:
         converted_series = typeset.cast_to_inferred(series.copy(deep=True))
-        assert series.dtype.kind != converted_series.dtype.kind or not (
-            (
-                converted_series.eq(series) | (converted_series.isna() & series.isna())
-            ).all()
-        )
+
+        if hasattr(series, "dtype") and hasattr(converted_series, "dtype"):
+            assert (
+                series.dtype.kind != converted_series.dtype.kind
+                or not sequences_equal(series, converted_series)
+            )
+        else:
+            assert not sequences_equal(series, converted_series)
+
     else:
-        converted_series = typeset.cast_to_inferred(series.copy(deep=True))
-        assert (
-            converted_series.eq(series) | (converted_series.isna() & series.isna())
-        ).all()
+        converted_series = typeset.cast_to_inferred(series)
+        assert sequences_equal(series, converted_series)
 
 
-def test_side_effects(series):
+def test_side_effects(name, series):
     reference = series.copy()
 
     typeset = CompleteSet()
     typeset.detect_type(series)
     typeset.infer_type(series)
 
-    # Check if NaN mask is equal
-    assert series.notna().eq(reference.notna()).all()
-    # Check if NonNaN values are equal
-    assert series[series.notna()].eq(reference[reference.notna()]).all()
+    assert sequences_equal(series, reference)
 
 
-def test_multiple_inference(series):
+def test_multiple_inference(name, series):
     """
     Notes:
         Copy to prevent possible side effects only for testing.
     """
     ts = CompleteSet()
 
-    inferred_type = ts.infer_type(series)
+    inferred_type = str(ts.infer_type(series))
 
-    series_convert = ts.cast_to_inferred(series.copy(deep=True))
+    series_convert = ts.cast_to_inferred(copy.copy(series))
 
-    initial_type_after_convert = ts.detect_type(series_convert.copy(deep=True))
+    initial_type_after_convert = str(ts.detect_type(series_convert))
     assert inferred_type == initial_type_after_convert
 
-    series_convert2 = ts.cast_to_inferred(series_convert.copy(deep=True))
+    series_convert2 = ts.cast_to_inferred(series_convert)
 
-    inferred_type_after_convert = ts.infer_type(series_convert2.copy(deep=True))
+    inferred_type_after_convert = str(ts.infer_type(series_convert2))
     assert initial_type_after_convert == inferred_type_after_convert
-
-    assert series_convert.isna().eq(series_convert2.isna()).all()
-    assert (
-        series_convert[series_convert.notna()]
-        .eq(series_convert2[series_convert2.notna()])
-        .all()
-    )
+    assert sequences_equal(series_convert, series_convert2)
